{% extends "wiki/article.html" %} {% load wiki_tags i18n sekizai_tags static %} {% block wiki_pagetitle %}{% trans "History" %}: {{ article.current_revision.title }}{% endblock %} {% block wiki_contents_tab %} {% include "wiki/includes/modals.html" %} {% addtoblock "js" %}
{% endaddtoblock %} {% addtoblock "css" %}
{% endaddtoblock %}

{% trans "Click each revision to see a list of edited lines. Click the Preview button to see how the article looked at this stage. At the bottom of this page, you can change to a particular revision or merge an old revision with the current one." %}

{% for revision in revisions %}
{% if revision == article.current_revision %} {% else %} {% endif %} {% include "wiki/includes/revision_info.html" with current_revision=article.current_revision %}
{% if revision.user_message %} {{ revision.user_message }} {% elif revision.automatic_log %} {{ revision.automatic_log }} {% else %} ({% trans "no log message" %}) {% endif %}
{% if revision == article.current_revision %} {% trans "Preview this revision" %} {% else %}
{% endif %} {% if article|can_write:user and not article.current_revision.locked %} {% endif %}

{% trans "Auto log:" %}
  {{ revision.automatic_log|default:"-"|linebreaksbr }}

{% if revision.previous_revision %}#{{revision.previous_revision.revision_number}}{% endif %} | #{{revision.revision_number}} | {% trans "Change" %}
--- | --- | ---

{% endfor %} {% include "wiki/includes/pagination.html" %} {% if revisions.count > 1 and article|can_write:user and not article.current_revision.locked %}
{% endif %}

# {% trans "Merge with current" %}

{% trans "When you merge a revision with the current, all data will be retained from both versions and merged at its approximate location from each revision." %} {% trans "After this, it's important to do a manual review." %}

{% endblock %}